[pve-devel] [PATCH pve-manager] make startall wait up to 60 seconds for quorum
Thomas Lamprecht
t.lamprecht at proxmox.com
Mon Nov 9 11:44:25 CET 2015
Previously we waited 10 seconds, in PVE 4 system sometimes need more
time to initialize all services so the didn't execute the startall
command even if a few seconds later cfs quorum was etablished.
This is a background process started from the pve-manager init
script, thus waiting doesn't interferes with other processes, so
wait long enough.
Signed-off-by: Thomas Lamprecht <t.lamprecht at proxmox.com>
---
PVE/API2/Nodes.pm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/PVE/API2/Nodes.pm b/PVE/API2/Nodes.pm
index 9b7bb9f..0581e1d 100644
--- a/PVE/API2/Nodes.pm
+++ b/PVE/API2/Nodes.pm
@@ -1234,8 +1234,8 @@ __PACKAGE__->register_method ({
$rpcenv->{type} = 'priv'; # to start tasks in background
- # wait up to 10 seconds for quorum
- for (my $i = 10; $i >= 0; $i--) {
+ # wait up to 60 seconds for quorum
+ for (my $i = 60; $i >= 0; $i--) {
last if PVE::Cluster::check_cfs_quorum($i != 0 ? 1 : 0);
sleep(1);
}
--
2.1.4
More information about the pve-devel
mailing list